@@ -2934,7 +2934,7 @@ def test_tkinterweb_tkhtml(pyi_builder):
 
         root = tkinter.Tk()
 
-        tkhtml_file, tkhtml_version, experimental = tkinterweb_tkhtml.get_tkhtml_file(None, False)
+        tkhtml_file, tkhtml_version, experimental = tkinterweb_tkhtml.get_tkhtml_file(None, experimental=False)
         print(f"Loading tkhtml version {tkhtml_version!r}: {tkhtml_file!r}")
         tkinterweb_tkhtml.load_tkhtml_file(root, tkhtml_file)
 
@@ -2945,6 +2945,40 @@ def test_tkinterweb_tkhtml(pyi_builder):
     """, run_from_path=True)
 
 
+@importorskip('tkinterweb_tkhtml')
+@importorskip('tkinterweb_tkhtml_extras')
+def test_tkinterweb_tkhtml_extras(pyi_builder):
+    # See comment in `test_tkinterweb` as to why `run_from_path=True` is required.
+    pyi_builder.test_source("""
+        import pathlib
+
+        import tkinterweb_tkhtml
+        import tkinterweb_tkhtml_extras
+
+        # Print all available tkhtml binaries
+        print("Available tkhtml binaries:", tkinterweb_tkhtml.ALL_TKHTML_BINARIES)
+
+        # Check that at least one binary is available in base and extras package, respectively.
+        base_path = pathlib.Path(tkinterweb_tkhtml.__file__).parent
+        extras_path = pathlib.Path(tkinterweb_tkhtml_extras.__file__).parent
+
+        found_base = False
+        found_extras = False
+
+        for path, name in tkinterweb_tkhtml.ALL_TKHTML_BINARIES:
+            path = pathlib.Path(path)
+            if base_path in path.parents or base_path == path:
+                print(f"Found binary in tkinterweb_tkhtml package: {name!r} in {str(path)!r}")
+                found_base = True
+            if extras_path in path.parents or base_path == path:
+                print(f"Found binary in tkinterweb_tkhtml_extras package: {name!r} in {str(path)!r}")
+                found_extras = True
+
+        assert found_base, "Did not find binary in tkinterweb_tkhtml package!"
+        assert extras_path, "Did not find binary in tkinterweb_tkhtml_extras package!"
+    """, run_from_path=True)
+
+
 @importorskip('narwhals')
 def test_narwhals(pyi_builder):
     pyi_builder.test_source("""
@@ -3107,3 +3141,53 @@ def test_pyecharts(pyi_builder):
         html = bar.render_embed()
         assert "Merchant A" in html
     """)
+
+
+@importorskip("pymeshlab")
+def test_pymeshlab(pyi_builder, tmp_path):
+    pyi_builder.test_source(
+        """
+        import sys
+        import pymeshlab
+
+        ms = pymeshlab.MeshSet()
+        ms.create_noisy_isosurface(resolution=16)
+        ms.save_current_mesh(sys.argv[1])
+        """,
+        # macOS wheel for pymeshlab includes a .framework bundle, so build and test an .app bundle as well, to check for
+        # codesign compliance.
+        pyi_args=['--windowed'] if is_darwin else [],
+        app_args=[str(tmp_path / 'output.ply')],
+    )
+
+
+@importorskip("fake_useragent")
+def test_fakeuseragent(pyi_builder):
+    pyi_builder.test_source("""
+        import fake_useragent
+
+        ua = fake_useragent.UserAgent()
+        print(ua.random)
+    """)
+
+
+@importorskip("ddgs")
+def test_ddgs(pyi_builder):
+    pyi_builder.test_source("""
+        import ddgs
+
+        results = ddgs.DDGS().text("PyInstaller", max_results=5)
+
+        # NOTE: do not try to print the results, as they may contain
+        # characters that are incompatible with encoding used on Windows
+        # for redirected stdout/stderr!
+        #for result in results:
+        #    print(result)
+    """)
+
+
+@importorskip("pytokens")
+def test_pytokens(pyi_builder):
+    pyi_builder.test_source("""
+        import pytokens
+    """)
